package com.mc.monkeynes.base;

import com.mc.monkeynes.gui.*;

/**
 * This is the starting point for the entire emulator. <br><br>
 * <b>Project Description:</b><br>
 * <p>The MonkeyNES project was originally conceived as a learning experiment.  The sort of project
 * a developer bored with his other project comes up with as a simultaneous form of torture and a 
 * raw chance to learn.</p>
 * <p>Another thing I decided very early on in the project's life was that I was going to do the 
 * development without aid of other people.  I would like to clarify that by explaining that I mean 
 * help in the form of development.  This does not stop me from doing lots of research on the 
 * internet to learn how the guts of an actual NES work.  For this reason the code was developed 
 * entirely by David Stephens.</p>
 * <p>Notes on sharing source code.  There are almost as many public licenses or general usage 
 * licenses or variations on both out there as there are projects that use them it seems.  I hate 
 * to break anyone's heart out there that may be drooling over the idea of getting the source 
 * code for MonkeyBrowser, but it's not going to be made available outside of extremely special 
 * situations.  In simple terms, unless you are a close personal friend of mine, or <i>maybe</i>
 * a potential employer you will very likely never see the source code.  The catch to this rule is 
 * that very early versions of the code are available due to the fact that they were available on the
 * <a href="http://www.monkeycoder.com/monkeynes">MonkeyNes site</a> to allow me to develop on the 
 * project from anywhere.  This obviously does not cover things such as disassembling the byte code 
 * in the class or jar files which I really have no control over.  You must remember that this entire 
 * project was planned and developed by one person, and handing out the code makes keeping it that 
 * way a very difficult thing to do.</p>
 * <p>While the source code is not available publicly, the program is.  Generally speaking the 
 * MonkeyNES project is Freeware, anyone is allowed to use it and anyone is allowed to 
 * distribute it intact.  In most cases this program is intended to be distributed as a stand-alone 
 * executable jar file called MonkeyNes.jar.</p>
 * <p>Thank you for your interest in this project.  Support is not offered in any way to the 
 * public at this time.  This program is known to work on some level or another on several 
 * platforms and was designed with a decent amount of cross-platform support, but it may not on 
 * yours and for this I appologize.</p>
 * Originally part of the MonkeyNes project.
 *
 * @author David Stephens
 */
public class MonkeyNes
{
  public MonkeyNes()
  {
    // Do nothing...
  }

  /**
   * Starting point of the entire program.
   */
  public void showGui()
  {
    MonkeyNesGui gui = new MonkeyNesGui();
    gui.show();    
  }
  
  /**
   * Used to start the emulator from the command line.  The syntax shown below is little more 
   * than a recommendation as far as the amount of memory given.  You will very likely find 
   * a line almost exactly as below in both <code>mb.bat</code> and in the manifest of the 
   * <code>MonkeyBrowser.jar</code> file.
   * <pre>Syntax:  java -Xmx256m com.mc.monkeynes.base.MonkeyNes</pre>
   * @param args Command line arguements.
   */
  public static void main( String[] args )
  {
    MonkeyNes mn = new MonkeyNes();
    mn.showGui();
  }
}