package com.mc.monkeynes.gui;

import java.awt.*;
import javax.swing.*;

public class StateLight extends JComponent
{
  private boolean   state            = false;
  private Color     trueColor        = null;
  private Color     trueBorderColor  = null;
  private Color     falseColor       = null;
  private Color     falseBorderColor = null;
  private Dimension totalSize        = new Dimension( 10, 16 );
  private Dimension lightSize        = new Dimension( 10, 10 );
  
  public StateLight( Color inTrueColor, Color inFalseColor )
  {
    state = false;
    initColors( inTrueColor, inTrueColor, inFalseColor, inFalseColor );
  }
  
  public StateLight( boolean inState, Color inTrueColor, Color inFalseColor )
  {
    state = inState;
    initColors( inTrueColor, inTrueColor, inFalseColor, inFalseColor );
  }
  
  public StateLight( Color inTrueColor, Color inTrueBorderColor, Color inFalseColor, Color inFalseBorderColor )
  {
    state = false;
    initColors( inTrueColor, inTrueBorderColor, inFalseColor, inFalseBorderColor );
  }
  
  public StateLight( boolean inState, Color inTrueColor, Color inTrueBorderColor, Color inFalseColor, Color inFalseBorderColor )
  {
    state = inState;
    initColors( inTrueColor, inTrueBorderColor, inFalseColor, inFalseBorderColor );
  }
  
  private void initColors( Color inTrueColor, Color inTrueBorderColor, Color inFalseColor, Color inFalseBorderColor )
  {
    trueColor        = inTrueColor;
    trueBorderColor  = inTrueBorderColor;
    falseColor       = inFalseColor;
    falseBorderColor = inFalseBorderColor;
    
    this.setSize( totalSize );
    this.setMinimumSize( totalSize );
    this.setMaximumSize( totalSize );
    this.setPreferredSize( totalSize );
  }

  public boolean getState()
  {
    return state;
  }
  
  public void setState( boolean inState )
  {
    state = inState;
    repaint();
  }
  
  public Dimension getPreferredSize()
  {
    return totalSize;
  }
  
  public void paint( Graphics g )
  {
    int top  = (int)(((double)totalSize.height / 2.0) - ((double)lightSize.height / 2.0));
    int left = (int)(((double)totalSize.width / 2.0) - ((double)lightSize.width / 2.0));
    
    if( state )
    {
      g.setColor( trueColor );
      g.fillOval( left, top, lightSize.width, lightSize.height );
      g.setColor( trueBorderColor );
      g.drawOval( left, top, lightSize.width-1, lightSize.height-1 );
    }
    else
    {
      g.setColor( falseColor );
      g.fillOval( left, top, lightSize.width, lightSize.height );
      g.setColor( falseBorderColor );
      g.drawOval( left, top, lightSize.width-1, lightSize.height-1 );
    }  
  }
}