package com.mc.monkeynes.hardware;

import java.util.*;

public class HighResolutionTimer extends Observable implements Runnable
{
  // All clock speeds are in Hz
  private long    clockSpeed  = 0L;
  private double  clockFactor = 0.0;
  private long    lastClock   = 0L;
  private boolean running     = false;
  
  public HighResolutionTimer( long inClockSpeed )
  {
    setClockSpeed( inClockSpeed );  
  }

  public void setClockSpeed( long inClockSpeed )
  {
    clockSpeed  = inClockSpeed;
    clockFactor = (clockSpeed / 1000.0);
  }

  public long getClockSpeed()
  {
    return clockSpeed;
  }
  
  public void startClock()
  {
    lastClock = System.currentTimeMillis();
    running   = true;
  }
  
  public void stopClock()
  {
    running   = false;
  }  
  
  public long getClocksPast()
  {
    long nowClock = System.currentTimeMillis();
    long retClocks = (int)((nowClock - lastClock) * clockFactor);
    
    lastClock = nowClock;
    
    return retClocks;
  }
  
  public void run()
  {
    long clocks = 0L;
    startClock();
    
    while( running )
    {
      if( (clocks = getClocksPast()) != 0 )
      {
        setChanged();
        notifyObservers( new TimerMessage( clocks ) );
      }
      Thread.yield();
    }
  }  
}