package com.mc.monkeynes.hardware;

public class NesRom
{
  // 40k                    = 40960
  // supermariobros.nes     = 40976
  // NES format header size = 16 bytes;
   
  public static final int ROM_FORMAT_UNKNOWN = 0;   
  public static final int ROM_FORMAT_INES    = 1;
  
  private int[]  romFormatHeaderSize   = { 0, 16 };
  
  private String        romFileName  = null;
  private int           romFormat    = ROM_FORMAT_UNKNOWN;
  private InesRomHeader inesHead     = null;
  private byte[]        headerData   = null;
  private int[]         romData      = null;
  
  public NesRom()
  {
    romFileName  = null;              
    romFormat    = ROM_FORMAT_UNKNOWN;
    inesHead     = null;
    headerData   = null;              
    romData      = null;              
  }
  
  // Setters -------------------------------------------------
  public void setRomFileName( String inRomFileName )
  {
    romFileName = inRomFileName;
  }
  
  public void setRomFormat( int inRomFormat )
  {
    romFormat = inRomFormat;
  }
  
  public void setHeaderData( byte[] inHeaderData )
  {
    headerData = inHeaderData;
    inesHead   = new InesRomHeader( headerData );
  }
  
  public void setRomData( int[] inRomData )
  {
    romData = inRomData;
  }      
  
  // Getters -------------------------------------------------
  public String getRomFileName()
  {
    return romFileName;
  }
  
  public int getRomFormat()
  {
    return romFormat;
  }

  public InesRomHeader getInesRomHeader()
  {
    return inesHead;
  }  
  
  public byte[] getHeaderData()
  {
    return headerData;
  }
  
  public int[] getRomData()
  {
    return romData;
  }
  
  // Rom Header Getters ----------------------------------------
  public int getRomFormatHeaderSize( int inRomFormat )
  {
    return romFormatHeaderSize[inRomFormat];
  }
  
  // Rom Page Getters ------------------------------------------
  // Pages start with 0!!
  public int[] getPrgRomPage( int pageNum )
  {
    if( pageNum < 0 || pageNum >= inesHead.getPrgRomPageCount() )
      return null;
    
    int start = pageNum * InesRomHeader.PRG_PAGE_SIZE;
    int stop  = start + InesRomHeader.PRG_PAGE_SIZE - 1;
    return read( start, stop );
  }

  // Pages start with 0!!
  public int[] getChrRomPage( int pageNum )
  {
    if( pageNum < 0 || pageNum >= inesHead.getChrRomPageCount() )
      return null;
    
    int start = inesHead.getPrgRomSize() + (pageNum * InesRomHeader.CHR_PAGE_SIZE);
    int stop  = start + InesRomHeader.CHR_PAGE_SIZE - 1;
    return read( start, stop );
  }   
 
  // General reading -------------------------------------------
  public int read( int addr )
  {
    return romData[addr];
  }

  public int[] read( int startAddr, int stopAddr )
  {
    int j = 0;
    int[] temp = new int[stopAddr - startAddr + 1];
    
    for( int i = startAddr; i <= stopAddr; i++ )
    {
      temp[j] = read(i);
      j++;
    }
    
    return temp;
  }
  
  // General Writing -------------------------------------------
  public void write( int addr, int val )
  {
    romData[addr] = val;
  }
  
  public void write( int startAddr, int[] data )
  {
    // writes the whole input buffer
    for( int i = 0; i < data.length; i++ )
      write( startAddr + i, data[i] );
  }

  public void write( int startAddr, int[] data, int len )
  {
    // writes up to len of the input buffer
    for( int i = 0; i < len; i++ )
      write( startAddr + i, data[i] );
  }
 
  // -----------------------------------------------------------
  public String toString()
  {
    StringBuffer sb = new StringBuffer();

    sb.append( "\nFile: " );
    sb.append( romFileName );
    sb.append( "\nFormat: " );
    sb.append( romFormat );
    sb.append( "\nHeader Size: " );
    sb.append( headerData.length );
    sb.append( "\nROM Size: " );
    sb.append( romData.length );
    sb.append( "\nPRG-ROM: " );
    sb.append( inesHead.getPrgRomSize() );
    sb.append( " [" + inesHead.getPrgRomPageCount() + " pages]" );
    sb.append( "\nCHR-ROM: " );
    sb.append( inesHead.getChrRomSize() );
    sb.append( " [" + inesHead.getChrRomPageCount() + " pages]" );
    sb.append( "\nMapper: " );
    sb.append( inesHead.getMapperNumber() );
    sb.append( "\n4-Screen VRAM: " );
    sb.append( inesHead.isFourScreenVram() );
    sb.append( "\nTrainer: " );
    sb.append( inesHead.isTrainerPresent() );
    sb.append( "\nSave RAM: " );
    sb.append( inesHead.isSramEnabled() );
    sb.append( "\nVert Mirror: " );
    sb.append( inesHead.isVertMirror() );
    sb.append( "\nHorz Mirror: " );
    sb.append( inesHead.isHorzMirror() );
    
    return sb.toString();
  }


}